import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import Button from '@sinoui/core/Button';
import Dialog from '@sinoui/core/Dialog';
import DialogContent from '@sinoui/core/DialogContent';
import DialogTitle from '@sinoui/core/DialogTitle';
import IconButton from '@sinoui/core/IconButton';
import React, { useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import styled from 'styled-components';
import { mergeCells } from '../../reducer';
import getCellValueInRange from '../../reducer/helper/getCellValueInRange';
import MergeIcon from './MergeIcon';
const StyledButton = styled(Button) `
  margin: 0 10px;
`;
const StyledButtonBox = styled.div `
  min-height: 52px;
  flex: 0 0 auto;
  display: flex;
  flex-direction: row;
  justify-content: center;
`;
const hasMergedCellInRange = (range, merges = []) => merges.find(([[sri, sci], [eri, eci]]) => sri >= range[0][0] &&
    sci >= range[0][1] &&
    eri <= range[1][0] &&
    eci <= range[1][1]);
function MergeButton({ selectedRange, disabled }) {
    const dispatch = useDispatch();
    const config = useSelector((state) => state.present);
    const [open, setOpen] = useState(false);
    const handleClick = () => {
        if (!selectedRange)
            return;
        if (hasMergedCellInRange(selectedRange, config.merges)) {
            // 单元格取消合并
            dispatch(mergeCells(selectedRange[0], selectedRange[1]));
            return;
        }
        // 对需要合并的单元格进行单元格的内容判定
        const cellValues = getCellValueInRange(selectedRange, config);
        if (cellValues.length > 1) {
            setOpen(true);
            return;
        }
        dispatch(mergeCells(selectedRange[0], selectedRange[1]));
    };
    const handleOk = () => {
        setOpen(false);
        if (!selectedRange)
            return;
        dispatch(mergeCells(selectedRange[0], selectedRange[1]));
    };
    return (_jsxs(_Fragment, { children: [_jsx(IconButton, { dense: true, onClick: handleClick, disabled: disabled, children: _jsx(MergeIcon, { viewBox: "0 0 1024 1024" }) }), _jsxs(Dialog, { open: open, onClose: () => setOpen(false), showCloseIcon: true, backdropClick: false, children: [_jsx(DialogTitle, { children: "\u5408\u5E76\u5355\u5143\u683C" }), _jsx(DialogContent, { children: "\u5408\u5E76\u5355\u5143\u683C\u65F6\uFF0C\u4EC5\u4FDD\u7559\u5DE6\u4E0A\u89D2\u7684\u503C\uFF0C\u800C\u653E\u5F03\u5176\u4ED6\u503C\u3002" }), _jsxs(StyledButtonBox, { children: [_jsx(StyledButton, { raised: true, onClick: handleOk, children: "\u786E\u8BA4" }), _jsx(StyledButton, { raised: true, onClick: () => setOpen(false), children: "\u53D6\u6D88" })] })] })] }));
}
export default React.memo(MergeButton);
