import { useState } from 'react';
import { useStore } from 'react-redux';
import { EDITOR_CHANGE, eventbus } from '../../constants';
import isActionHelper from '../../utils/isActionHelper';
import useWatchProp from '../../utils/useWatchProp';
import useListenEvent from '../useEventListener';
/**
 * 判断指定样式是否已在选中区域中设置的hook
 *
 * @param style 样式名称
 * @param selectedRange 选中的单元格区域
 * @param isActiveCallback 选中的单元格区域是否有指定样式的回调函数
 * @returns 返回指定样式是否已设置
 */
export default function useSingleStyleActive(style, selectedRange, isActiveCallback) {
    const state = useStore().getState().present;
    const [isActive, setIsActive] = useState(false);
    useWatchProp(selectedRange, () => {
        if (selectedRange) {
            setIsActive(isActionHelper(state, selectedRange, style));
        }
    });
    const handleChange = (editor) => {
        if (editor) {
            setIsActive(isActiveCallback(editor));
        }
    };
    useListenEvent(eventbus, EDITOR_CHANGE, handleChange);
    return [isActive, setIsActive];
}
