import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { memo } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import styled from 'styled-components';
import { DEFAULT_MENU_WIDTH } from '../constants';
import { copyCell, cutCell, deleteCol, deleteRow, insertCol, insertRow, } from '../reducer';
import drawRange from './drawRange';
const Wrapper = styled.div `
  position: fixed;
  background: white;
  box-shadow: 0px 2px 10px #999999;
  z-index: 100;
`;
const MenuItem = styled.div `
  padding: 8px 10px;
  width: ${DEFAULT_MENU_WIDTH}px;
  cursor: default;
  font-family: 'Helvetica Neue', 'PingFang SC', 'Hiragino Sans GB',
    'Microsoft YaHei', Arial, sans-serif;
  font-size: 12px;
  cursor: pointer;

  &:hover {
    background: #eee;
  }
`;
const Devider = styled.div `
  width: 100%;
  height: 1px;
  border: none;
  margin: 1px;
  background: #ddd;
`;
function ContextMenu({ pos, contextMenuShow, setContextMenuShow, selectedRange, copyOrCut, setCopyOrCut, cellRangeForCopyOrCut, setCellRangeForCopyOrCut, setSelectedRange, }) {
    const dispatch = useDispatch();
    const merges = useSelector((state) => state.present.merges);
    if (!contextMenuShow || !pos) {
        return null;
    }
    const handleRowInsert = () => {
        if (!selectedRange) {
            return;
        }
        dispatch(insertRow(selectedRange[0][0]));
        setContextMenuShow(false);
    };
    const handleColInsert = () => {
        if (!selectedRange)
            return;
        dispatch(insertCol(selectedRange[0][1]));
        setContextMenuShow(false);
    };
    const handleRowDelete = () => {
        if (!selectedRange)
            return;
        dispatch(deleteRow(selectedRange[0][0], selectedRange[1][0] - selectedRange[0][0] + 1));
        setContextMenuShow(false);
    };
    const handleColDelete = () => {
        if (!selectedRange)
            return;
        dispatch(deleteCol(selectedRange[0][1], selectedRange[1][1]));
        setContextMenuShow(false);
    };
    const handleCopyOrCutCell = (type) => {
        if (!selectedRange)
            return;
        setCopyOrCut(type);
        setCellRangeForCopyOrCut(selectedRange);
        setContextMenuShow(false);
    };
    const handlePasteCell = () => {
        if (!cellRangeForCopyOrCut || !selectedRange) {
            return;
        }
        if (copyOrCut === 'copy') {
            dispatch(copyCell(cellRangeForCopyOrCut, selectedRange[0]));
        }
        else if (copyOrCut === 'cut') {
            dispatch(cutCell(cellRangeForCopyOrCut, selectedRange[0]));
        }
        let endPos = [
            selectedRange[0][0] +
                cellRangeForCopyOrCut[1][0] -
                cellRangeForCopyOrCut[0][0],
            selectedRange[0][1] +
                cellRangeForCopyOrCut[1][1] -
                cellRangeForCopyOrCut[0][1],
        ];
        endPos =
            merges?.find(([[sri, sci], [eri, eci]]) => sri <= endPos[0] &&
                endPos[0] <= eri &&
                sci <= endPos[1] &&
                endPos[1] <= eci)?.[0] ?? endPos;
        drawRange(selectedRange[0], endPos);
        setSelectedRange([selectedRange[0], endPos]);
        setContextMenuShow(false);
    };
    return (_jsxs(Wrapper, { style: { left: `${pos[0]}px`, top: `${pos[1]}px` }, children: [_jsx(MenuItem, { onClick: () => handleCopyOrCutCell('copy'), children: "\u590D\u5236" }), _jsx(MenuItem, { onClick: () => handleCopyOrCutCell('cut'), children: "\u526A\u5207" }), _jsx(MenuItem, { onClick: handlePasteCell, children: "\u7C98\u8D34" }), _jsx(Devider, {}), _jsx(MenuItem, { onClick: handleRowInsert, children: "\u63D2\u5165\u884C" }), _jsx(MenuItem, { onClick: handleColInsert, children: "\u63D2\u5165\u5217" }), _jsx(MenuItem, { onClick: handleRowDelete, children: "\u5220\u9664\u884C" }), _jsx(MenuItem, { onClick: handleColDelete, children: "\u5220\u9664\u5217" })] }));
}
export default memo(ContextMenu);
