import { jsx as _jsx } from "react/jsx-runtime";
import { CellValueRenderer } from '@sinoform/print-out-core';
import { memo, useCallback, useMemo } from 'react';
import isEqual from 'react-fast-compare';
import { useDispatch, useSelector } from 'react-redux';
import { createEditor, Transforms } from 'slate';
import { withHistory } from 'slate-history';
import { ReactEditor, withReact } from 'slate-react';
import SlateEditor from '../components/slate-editor';
import { ActionType } from '../reducer';
import withShortcuts from '../utils/withShortcuts';
function Td({ cell, rowIdx, colIdx, style, fields, setEditor, handleTdDoubleClick, height, width, }) {
    const dispatch = useDispatch();
    const isEditing = useSelector((reduxState) => {
        const [rowIndex, columnIndex] = reduxState.present.editingCell ?? [-1, -1];
        return rowIndex === rowIdx && columnIndex === colIdx;
    });
    const { horizontal, vertical, ...border } = style;
    const editor = useMemo(() => withShortcuts(withHistory(withReact(createEditor()))), []);
    const handleDoubleClick = useCallback(() => {
        const pos = [rowIdx, colIdx];
        if (isEditing) {
            return;
        }
        dispatch({
            type: ActionType.SET_EDITING_CELL,
            payload: pos,
        });
        setEditor(editor);
        if (handleTdDoubleClick) {
            handleTdDoubleClick();
        }
        // 双击时让editor获取焦点
        setTimeout(() => {
            ReactEditor.focus(editor);
            if (editor.children &&
                editor.children[0].children[0].text.length === 0) {
                editor.insertText(' ');
            }
            Transforms.setSelection(editor, {
                anchor: { path: [0, 0], offset: 1 },
                focus: { path: [0, 0], offset: 1 },
            });
        });
    }, [
        rowIdx,
        colIdx,
        isEditing,
        dispatch,
        setEditor,
        editor,
        handleTdDoubleClick,
    ]);
    const getReadOnlyValue = (cellValue) => {
        if (!cellValue) {
            return [];
        }
        return cellValue.map((item) => ({ segment: item }));
    };
    const tdStyle = useMemo(() => ({
        ...border,
        backgroundColor: cell?.style?.backgroundColor
            ? cell.style.backgroundColor
            : 'transparent',
    }), [border, cell?.style?.backgroundColor]);
    return (_jsx("td", { className: "custom-print-table-td", id: `${rowIdx}-${colIdx}`, colSpan: (cell?.merge?.[1] ?? 0) + 1, rowSpan: (cell?.merge?.[0] ?? 0) + 1, style: tdStyle, height: height, "data-rowid": rowIdx, "data-colid": colIdx, "data-merge": JSON.stringify(cell?.merge ?? [0, 0]), onDoubleClick: handleDoubleClick, children: _jsx("div", { style: {
                width: '100%',
                height: `${height}px`,
                display: 'flex',
                overflow: 'hidden',
                textAlign: horizontal ?? 'left',
                alignItems: vertical ?? 'center',
            }, children: !isEditing ? (_jsx(CellValueRenderer, { value: getReadOnlyValue(cell?.value), fields: fields, isInDesigner: true })) : (_jsx(SlateEditor, { value: cell?.value, editor: editor, bgColor: cell?.style?.backgroundColor, width: width, rowIdx: rowIdx, colIdx: colIdx, fields: fields })) }) }));
}
// eslint-disable-next-line react/display-name
const TdComp = memo(Td, (prev, next) => {
    if (!isEqual(prev.cell, next.cell) ||
        !isEqual(prev.style, next.style) ||
        prev.width !== next.width ||
        prev.height !== next.height) {
        return false;
    }
    return true;
});
export default TdComp;
