import { genToken } from '@sinoform/helper-formula-analysis';
/**
 * 获取单元格内所有的表达式
 *
 * @param value   单元格的值
 */
function getAllCodeTokensInCell(value) {
    const codes = [];
    value.forEach((paragraph) => {
        if (paragraph.children.length > 0) {
            paragraph.children.forEach((item) => {
                const matches = item.text.match(/\$\{.*?\}/g) ?? [];
                codes.push(...matches);
            });
        }
    });
    const tokens = [];
    codes.forEach((item) => tokens.push(...genToken(item)));
    return tokens;
}
const checkIsSubForm = (fields, token) => fields.some((field) => {
    if (field.type === 'form' || field.type === 'modalForm') {
        return field.title === token.content;
    }
    if (field.children) {
        return checkIsSubForm(field.children, token);
    }
    return false;
});
export function getAllSubFieldFromToken(tokens, fields) {
    const subFormItem = tokens
        .filter((item) => item.type === 'variable' && checkIsSubForm(fields, item))
        .map((item) => item.content);
    return new Set(subFormItem);
}
/**
 * 获取当前行所有单元格公式的token信息
 *
 * @param draft   状态
 * @param cellPos 单元格位置
 * @param value   表达式
 */
export function getAllCodeTokensInRow(draft, cellPos, value) {
    const [rowIdx, colIdx] = cellPos;
    const { rows, cols } = draft;
    const tokens = [];
    for (let i = 0; i < cols.len; i += 1) {
        if (colIdx === i) {
            tokens.push(...getAllCodeTokensInCell(value));
        }
        else if (rows[rowIdx]?.cells?.[i]?.value) {
            tokens.push(...getAllCodeTokensInCell(rows[rowIdx].cells[i].value));
        }
    }
    return tokens;
}
/**
 * 同一行单元格的表达式中不能出现不同子表单的表单项
 * 表达式中出现了子表单选项一律视为表单项的值，不考虑其作为打印值的场景
 *
 * @param draft     状态
 * @param cellPos   单元格位置
 * @param value     表达式的值
 * @param fields    表单项集合
 */
export default function checkSubFieldInRow(draft, cellPos, value, fields = []) {
    const tokens = getAllCodeTokensInRow(draft, cellPos, value);
    const set = getAllSubFieldFromToken(tokens, fields);
    return set.size > 1;
}
