import { Editor, Transforms, Text } from 'slate';
const CustomEditor = {
    isBoldMarkActive(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => n.bold === true,
            universal: true,
        });
        return !!match;
    },
    isItalicActive(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => n.italic === true,
        });
        return !!match;
    },
    isUnderLineMarkActive(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => n.underLine === true,
        });
        return !!match;
    },
    isDeleteLineMarkActive(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => n.deleteLine === true,
        });
        return !!match;
    },
    getFontFamily(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => !!n.fontFamily,
        });
        return match && match[0]?.fontFamily;
    },
    getFontSize(editor) {
        const [match] = Editor.nodes(editor, {
            match: (n) => !!n.fontSize,
        });
        return match && match[0]?.fontSize;
    },
    toggleBoldMark(editor) {
        const isActive = CustomEditor.isBoldMarkActive(editor);
        Transforms.setNodes(editor, { bold: isActive ? undefined : true }, { match: (n) => Text.isText(n), split: true });
    },
    toggleItalicMark(editor) {
        const isActive = CustomEditor.isItalicActive(editor);
        Transforms.setNodes(editor, { italic: isActive ? null : true }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
    toggleUnderLineMark(editor) {
        const isActive = CustomEditor.isUnderLineMarkActive(editor);
        Transforms.setNodes(editor, { underLine: isActive ? null : true }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
    toggleDeleteLineMark(editor) {
        const isActive = CustomEditor.isDeleteLineMarkActive(editor);
        Transforms.setNodes(editor, { deleteLine: isActive ? null : true }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
    changeTextColor(editor, color) {
        Transforms.setNodes(editor, { color }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
    toggeleFontSize(editor, fontSize) {
        Transforms.setNodes(editor, { fontSize }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
    toggeleFontFamily(editor, fontFamily) {
        Transforms.setNodes(editor, { fontFamily }, {
            match: (n) => Text.isText(n),
            split: true,
        });
    },
};
export default CustomEditor;
