"use strict";

var _interopRequireDefault = /*#__PURE__*/require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = withShortcuts;
var _objectSpread2 = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("@babel/runtime/helpers/objectSpread2"));
var _slate = /*#__PURE__*/require("slate");
var _getNodeInfoByPoint = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("./getNodeInfoByPoint"));
var _isCodeType = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("./isCodeType"));
/* eslint-disable no-param-reassign */

function withShortcuts(editor) {
  var insertText = editor.insertText,
    deleteBackward = editor.deleteBackward,
    deleteForward = editor.deleteForward;
  editor.insertText = function (text) {
    var selection = editor.selection;
    if (text === '{' && selection && _slate.Range.isCollapsed(selection)) {
      if ((0, _isCodeType.default)(editor, selection.focus)) {
        insertText(text);
        return;
      }
      var anchor = selection.anchor;
      var block = _slate.Editor.above(editor, {
        match: function match(n) {
          return _slate.Editor.isBlock(editor, n);
        }
      });
      var path = block ? block[1] : [];
      var start = _slate.Editor.start(editor, path);
      var range = {
        anchor: anchor,
        focus: start
      };
      var beforeText = _slate.Editor.string(editor, range);
      if (beforeText.endsWith('$')) {
        insertText('{}');
        var selectRange = {
          anchor: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, selection.anchor), {}, {
            offset: selection.anchor.offset + 1
          }),
          focus: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, selection.focus), {}, {
            offset: selection.focus.offset + 1
          })
        };
        _slate.Transforms.setSelection(editor, selectRange);
        return;
      }
    }
    insertText(text);
  };
  editor.deleteBackward = function () {
    var _editor$selection = editor.selection,
      anchor = _editor$selection.anchor,
      focus = _editor$selection.focus;
    if (_slate.Point.equals(anchor, focus) && (0, _isCodeType.default)(editor, focus)) {
      var focusCodeBlock = (0, _getNodeInfoByPoint.default)(editor, focus);
      if (focus.offset === focusCodeBlock.end) {
        _slate.Transforms.select(editor, {
          anchor: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, anchor), {}, {
            offset: focusCodeBlock.start
          }),
          focus: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, focus), {}, {
            offset: focusCodeBlock.end
          })
        });
        return;
      }
    }
    deleteBackward.apply(void 0, arguments);
  };
  editor.deleteForward = function () {
    var _editor$selection2 = editor.selection,
      anchor = _editor$selection2.anchor,
      focus = _editor$selection2.focus;
    if (_slate.Point.equals(anchor, focus) && (0, _isCodeType.default)(editor, focus)) {
      var focusCodeBlock = (0, _getNodeInfoByPoint.default)(editor, focus);
      if (focus.offset === focusCodeBlock.start) {
        _slate.Transforms.select(editor, {
          anchor: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, anchor), {}, {
            offset: focusCodeBlock.start
          }),
          focus: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, focus), {}, {
            offset: focusCodeBlock.end
          })
        });
        return;
      }
    }
    deleteForward.apply(void 0, arguments);
  };
  return editor;
}